@@ -27,7 +27,6 @@
 #include <gnu_gama/local/gamadata.h>
 #include <gnu_gama/version.h>
 #include <gnu_gama/statan.h>
-#include <gnu_gama/size_to.h>
 #include <iostream>
 
 using namespace GNU_gama::local;
@@ -351,7 +350,7 @@ void LocalNetwork2sql::write(std::ostream& ostr, std::string conf)
     {
       const int N = 1000;  // varchar('N') in gnu_gama_local_descriptions table;
       int indx = 0;
-      while (indx*N < size_to<int>(localNetwork.description.length()))
+      while (indx*N < static_cast<int>(localNetwork.description.length()))
         {
           const std::string& s = localNetwork.description.substr(indx*N, N);
           std::string description;
@@ -758,7 +757,7 @@ void LocalNetwork2sql::write(std::ostream& ostr, std::string conf)
 
         ObservationSummaryCounter counter;
 
-        for (int i=1; i<=netinfo->sum_observations(); i++)
+        for (int i=1; i<=netinfo->observations_count(); i++)
           netinfo->ptr_obs(i)->accept(&counter);
 
         ostr << "insert into gnu_gama_local_adj_observations_summary "
@@ -782,8 +781,8 @@ void LocalNetwork2sql::write(std::ostream& ostr, std::string conf)
              << "(conf_id, equations, unknowns, deg_freedom, defect, sum_squares, connected) "
              << "values ("
              << cnfg()                        << ", "
-             << netinfo->sum_observations()   << ", "
-             << netinfo->sum_unknowns()       << ", "
+             << netinfo->observations_count()   << ", "
+             << netinfo->unknowns_count()       << ", "
              << netinfo->degrees_of_freedom() << ", "
              << netinfo->null_space()         << ", "
              << netinfo->trans_VWV()          << ", "
@@ -892,7 +891,7 @@ void LocalNetwork2sql::write(std::ostream& ostr, std::string conf)
 
 
       { // orientation shifts
-        for (int i=1; i<=netinfo->sum_unknowns(); i++)
+        for (int i=1; i<=netinfo->unknowns_count(); i++)
           {
             if (netinfo->unknown_type(i) != 'R') continue;
 
@@ -908,7 +907,7 @@ void LocalNetwork2sql::write(std::ostream& ostr, std::string conf)
           }
       }
 
-      std::vector<int> ind(netinfo->sum_unknowns() + 1);
+      std::vector<int> ind(netinfo->unknowns_count() + 1);
       {
         int dim = 0;
         for (PointData::const_iterator
@@ -925,7 +924,7 @@ void LocalNetwork2sql::write(std::ostream& ostr, std::string conf)
             }
           }
 
-        for (int i=1; i<=netinfo->sum_unknowns(); i++)
+        for (int i=1; i<=netinfo->unknowns_count(); i++)
           if (netinfo->unknown_type(i) == 'R')
             {
               StandPoint* k = netinfo->unknown_standpoint(i);
@@ -935,7 +934,7 @@ void LocalNetwork2sql::write(std::ostream& ostr, std::string conf)
 
 
       { // covariance matrix
-        int dim  = netinfo->sum_unknowns();
+        int dim  = netinfo->unknowns_count();
         int band = netinfo->adj_covband();
         if (band < 0) band = dim-1;
 
@@ -954,7 +953,7 @@ void LocalNetwork2sql::write(std::ostream& ostr, std::string conf)
 
 
       { // original indexes
-        for (int i=1; i<= netinfo->sum_unknowns(); i++)
+        for (int i=1; i<= netinfo->unknowns_count(); i++)
           {
             ostr << "insert into gnu_gama_local_adj_original_indexes "
                  << "(conf_id, indx, adj_indx) "
@@ -967,7 +966,7 @@ void LocalNetwork2sql::write(std::ostream& ostr, std::string conf)
       { // observations
         WriteSQLVisitor writeVisitor(ostr, netinfo);
 
-        for (int indx=1; indx<=netinfo->sum_observations(); indx++)
+        for (int indx=1; indx<=netinfo->observations_count(); indx++)
           {
             Observation* pm = netinfo->ptr_obs(indx);
 
