@@ -34,7 +34,6 @@
 #include <gnu_gama/intfloat.h>
 #include <gnu_gama/gon2deg.h>
 #include <gnu_gama/xsd.h>
-#include <gnu_gama/size_to.h>
 
 namespace {
   typedef std::pair<double, bool> DB_pair;
@@ -1036,7 +1035,7 @@ namespace GNU_gama { namespace local {
             // scaling of rows/columns corresponding to covariances
             // given in sexagesimal seconds
             std::vector<DB_pair>::iterator s = sigma.begin();
-            for (int i=1; i<=size_to<int>(sigma.size()); ++i, ++s)
+            for (int i=1; i<=static_cast<int>(sigma.size()); ++i, ++s)
               {
                 if ((*s).second) standpoint->scaleCov(i, 1.0/0.324);
               }
@@ -1285,7 +1284,7 @@ namespace GNU_gama { namespace local {
   int GKFparser::finish_coords()
   {
     if (!idim) return error(T_GKF_coordinates_without_covariance_matrix);
-    if (idim != size_to<int>(coordinates->observation_list.size()))
+    if (idim != static_cast<int>(coordinates->observation_list.size()))
       return error("T_GKF_cov_dim_differs_from_number_of_coordinates");
 
     coordinates->update();
@@ -1460,7 +1459,7 @@ namespace GNU_gama { namespace local {
   int GKFparser::finish_vectors()
   {
     if (!idim) return error(T_GKF_vectors_without_covariance_matrix);
-    if (idim != size_to<int>(vectors->observation_list.size()))
+    if (idim != static_cast<int>(vectors->observation_list.size()))
       return error("T_GKF_cov_dim_differs_from_number_of_vectors");
 
     vectors->update();         // bind observations to the cluster
